@@ -18,7 +18,7 @@ use Lemonldap::NG::Common::Session;
 
 use base qw(Lemonldap::NG::Handler::SharedConf);
 
-our $VERSION = '1.9.0';
+our $VERSION = '1.9.1';
 
 sub handler {
     my ( $class, $request ) = ( __PACKAGE__, shift );
@@ -217,7 +217,7 @@ L<http://lemonldap-ng.org/>
 =head1 BUG REPORT
 
 Use OW2 system to report bug or ask for features:
-L<http://jira.ow2.org>
+L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 
 =head1 DOWNLOAD
 
